from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AfSettings:
	"""AfSettings commands group definition. 6 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("afSettings", core, parent)

	@property
	def audioOutput(self):
		"""audioOutput commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_audioOutput'):
			from .AfSettings_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	# noinspection PyTypeChecker
	def get_connector(self) -> enums.AudioConnector:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:CONNector \n
		Snippet: value: enums.AudioConnector = driver.source.avionics.generator.markerBeacon.afSettings.get_connector() \n
		Selects the output connector for the generated AF signal (AF1 OUT or AF2 OUT) . \n
			:return: connector: AF1O | AF2O
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.AudioConnector)

	def set_connector(self, connector: enums.AudioConnector) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:CONNector \n
		Snippet: driver.source.avionics.generator.markerBeacon.afSettings.set_connector(connector = enums.AudioConnector.AF1O) \n
		Selects the output connector for the generated AF signal (AF1 OUT or AF2 OUT) . \n
			:param connector: AF1O | AF2O
		"""
		param = Conversions.enum_scalar_to_str(connector, enums.AudioConnector)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:CONNector {param}')

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.markerBeacon.afSettings.get_enable() \n
		Enables or disables the modulation of the RF carrier with the marker beacon audio tone. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:ENABle \n
		Snippet: driver.source.avionics.generator.markerBeacon.afSettings.set_enable(enable = False) \n
		Enables or disables the modulation of the RF carrier with the marker beacon audio tone. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:ENABle {param}')

	def get_mod_depth(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:MDEPth \n
		Snippet: value: float = driver.source.avionics.generator.markerBeacon.afSettings.get_mod_depth() \n
		Sets the modulation depth for amplitude modulation of the carrier. The sum of the modulation depths for all enabled
		components must not exceed 100 %. \n
			:return: mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:MDEPth?')
		return Conversions.str_to_float(response)

	def set_mod_depth(self, mod_depth: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:MDEPth \n
		Snippet: driver.source.avionics.generator.markerBeacon.afSettings.set_mod_depth(mod_depth = 1.0) \n
		Sets the modulation depth for amplitude modulation of the carrier. The sum of the modulation depths for all enabled
		components must not exceed 100 %. \n
			:param mod_depth: Range: 0 % to 100 %, Unit: %
		"""
		param = Conversions.decimal_value_to_str(mod_depth)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:MDEPth {param}')

	def get_frequency(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:FREQuency \n
		Snippet: value: float = driver.source.avionics.generator.markerBeacon.afSettings.get_frequency() \n
		Sets the audio frequency of the tone to be modulated to the carrier. \n
			:return: freq: Range: 0 Hz to 10 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, freq: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:FREQuency \n
		Snippet: driver.source.avionics.generator.markerBeacon.afSettings.set_frequency(freq = 1.0) \n
		Sets the audio frequency of the tone to be modulated to the carrier. \n
			:param freq: Range: 0 Hz to 10 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:MBEacon:AFSettings:FREQuency {param}')

	def clone(self) -> 'AfSettings':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AfSettings(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.DeltaMode, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:LEVel:DELTa:MODE \n
		Snippet: driver.configure.afRf.measurement.audioInput.level.delta.mode.set(mode = enums.DeltaMode.MEAS, audioInput = repcap.AudioInput.Default) \n
		No command help available \n
			:param mode: NONE | MEAS | USER
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		param = Conversions.enum_scalar_to_str(mode, enums.DeltaMode)
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:LEVel:DELTa:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, audioInput=repcap.AudioInput.Default) -> enums.DeltaMode:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:LEVel:DELTa:MODE \n
		Snippet: value: enums.DeltaMode = driver.configure.afRf.measurement.audioInput.level.delta.mode.get(audioInput = repcap.AudioInput.Default) \n
		No command help available \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: mode: NONE | MEAS | USER"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		response = self._core.io.query_str(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:LEVel:DELTa:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.DeltaMode)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Xvalues:
	"""Xvalues commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("xvalues", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:VSE:MEASurement<Instance>:SDIStribute:XVALues \n
		Snippet: value: List[float] = driver.vse.measurement.sdistribute.xvalues.fetch() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: xvals: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:VSE:MEASurement<Instance>:SDIStribute:XVALues?', suppressed)
		return response



from enum import Enum
from .Internal.RepeatedCapability import VALUE_DEFAULT
from .Internal.RepeatedCapability import VALUE_EMPTY


# noinspection SpellCheckingInspection
class Instance(Enum):
	"""Global Repeated capability Instance \n
	Selects the instrument"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Inst1 = 1
	Inst2 = 2
	Inst3 = 3
	Inst4 = 4
	Inst5 = 5
	Inst6 = 6
	Inst7 = 7
	Inst8 = 8
	Inst9 = 9
	Inst10 = 10
	Inst11 = 11
	Inst12 = 12
	Inst13 = 13
	Inst14 = 14
	Inst15 = 15
	Inst16 = 16
	Inst17 = 17
	Inst18 = 18
	Inst19 = 19
	Inst20 = 20
	Inst21 = 21
	Inst22 = 22
	Inst23 = 23
	Inst24 = 24
	Inst25 = 25
	Inst26 = 26
	Inst27 = 27
	Inst28 = 28
	Inst29 = 29
	Inst30 = 30
	Inst31 = 31
	Inst32 = 32


# noinspection SpellCheckingInspection
class AudioInput(Enum):
	"""Repeated capability AudioInput \n
	Selects the AF index"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class AudioOutput(Enum):
	"""Repeated capability AudioOutput \n
	Selects the connector number"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class Battery(Enum):
	"""Repeated capability Battery \n
	Index of battery"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Ix1 = 1
	Ix2 = 2


# noinspection SpellCheckingInspection
class Bit(Enum):
	"""Repeated capability Bit"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12


# noinspection SpellCheckingInspection
class Channel(Enum):
	"""Repeated capability Channel \n
	Selects the path input"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class Connector(Enum):
	"""Repeated capability Connector \n
	Selects the connector"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8


# noinspection SpellCheckingInspection
class FrequencyLobe(Enum):
	"""Repeated capability FrequencyLobe \n
	index"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class Instrument(Enum):
	"""Repeated capability Instrument \n
	instrument"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2


# noinspection SpellCheckingInspection
class InternalGen(Enum):
	"""Repeated capability InternalGen \n
	Number of DigitalGenerator"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4


# noinspection SpellCheckingInspection
class Marker(Enum):
	"""Repeated capability Marker \n
	Selects the marker"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5


# noinspection SpellCheckingInspection
class MarkerOther(Enum):
	"""Repeated capability MarkerOther \n
	Selects the Marker"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5


# noinspection SpellCheckingInspection
class Notch(Enum):
	"""Repeated capability Notch \n
	Select the Notch filter index"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3


# noinspection SpellCheckingInspection
class Relay(Enum):
	"""Repeated capability Relay \n
	Index of Relay"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Ix1 = 1
	Ix2 = 2


# noinspection SpellCheckingInspection
class ToneNumber(Enum):
	"""Repeated capability ToneNumber \n
	no"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Nr1 = 1
	Nr2 = 2
	Nr3 = 3
	Nr4 = 4
	Nr5 = 5
	Nr6 = 6
	Nr7 = 7
	Nr8 = 8
	Nr9 = 9
	Nr10 = 10
	Nr11 = 11
	Nr12 = 12
	Nr13 = 13
	Nr14 = 14
	Nr15 = 15
	Nr16 = 16
	Nr17 = 17
	Nr18 = 18
	Nr19 = 19
	Nr20 = 20


# noinspection SpellCheckingInspection
class TTL(Enum):
	"""Repeated capability TTL \n
	Index of TTL Register"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Ix1 = 1
	Ix2 = 2


# noinspection SpellCheckingInspection
class Window(Enum):
	"""Repeated capability Window \n
	1-n"""
	Empty = VALUE_EMPTY
	Default = VALUE_DEFAULT
	Win1 = 1
	Win2 = 2
	Win3 = 3
	Win4 = 4
	Win5 = 5
	Win6 = 6
	Win7 = 7
	Win8 = 8
	Win9 = 9
	Win10 = 10
	Win11 = 11
	Win12 = 12
	Win13 = 13
	Win14 = 14
	Win15 = 15
	Win16 = 16
	Win17 = 17
	Win18 = 18
	Win19 = 19
	Win20 = 20
	Win21 = 21
	Win22 = 22
	Win23 = 23
	Win24 = 24
	Win25 = 25
	Win26 = 26
	Win27 = 27
	Win28 = 28
	Win29 = 29
	Win30 = 30
	Win31 = 31
	Win32 = 32



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delta:
	"""Delta commands group definition. 4 total commands, 1 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("delta", core, parent)

	@property
	def update(self):
		"""update commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_update'):
			from .Delta_.Update import Update
			self._update = Update(self._core, self._base)
		return self._update

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.DeltaMode:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:MODE \n
		Snippet: value: enums.DeltaMode = driver.configure.afRf.measurement.demodulation.frequency.delta.get_mode() \n
		No command help available \n
			:return: mode: NONE | MEAS | USER
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.DeltaMode)

	def set_mode(self, mode: enums.DeltaMode) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:MODE \n
		Snippet: driver.configure.afRf.measurement.demodulation.frequency.delta.set_mode(mode = enums.DeltaMode.MEAS) \n
		No command help available \n
			:param mode: NONE | MEAS | USER
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.DeltaMode)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:MODE {param}')

	def get_user(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:USER \n
		Snippet: value: float = driver.configure.afRf.measurement.demodulation.frequency.delta.get_user() \n
		No command help available \n
			:return: user_val: Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:USER?')
		return Conversions.str_to_float(response)

	def set_user(self, user_val: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:USER \n
		Snippet: driver.configure.afRf.measurement.demodulation.frequency.delta.set_user(user_val = 1.0) \n
		No command help available \n
			:param user_val: Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(user_val)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:USER {param}')

	def get_measured(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:MEASured \n
		Snippet: value: float = driver.configure.afRf.measurement.demodulation.frequency.delta.get_measured() \n
		No command help available \n
			:return: meas_val: Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation:FREQuency:DELTa:MEASured?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Delta':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Delta(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bpass:
	"""Bpass commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bpass", core, parent)

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable_Left: bool: OFF | ON Disable or enable filter for left SPDIF channel
			- Enable_Right: bool: OFF | ON Disable or enable filter for right SPDIF channel"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable_Left'),
			ArgStruct.scalar_bool('Enable_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable_Left: bool = None
			self.Enable_Right: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:ENABle \n
		Snippet: value: EnableStruct = driver.configure.afRf.measurement.spdif.filterPy.bpass.get_enable() \n
		Enables or disables the variable bandpass filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:ENABle \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.bpass.set_enable(value = EnableStruct()) \n
		Enables or disables the variable bandpass filter in the SPDIF input path. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:ENABle', value)

	# noinspection PyTypeChecker
	class CfrequencyStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Frequency_Left: float: Frequency for left SPDIF channel Unit: Hz
			- Frequency_Right: float: Frequency for right SPDIF channel Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Frequency_Left'),
			ArgStruct.scalar_float('Frequency_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency_Left: float = None
			self.Frequency_Right: float = None

	def get_cfrequency(self) -> CfrequencyStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:CFRequency \n
		Snippet: value: CfrequencyStruct = driver.configure.afRf.measurement.spdif.filterPy.bpass.get_cfrequency() \n
		Configures the center frequency of the variable bandpass filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for CfrequencyStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:CFRequency?', self.__class__.CfrequencyStruct())

	def set_cfrequency(self, value: CfrequencyStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:CFRequency \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.bpass.set_cfrequency(value = CfrequencyStruct()) \n
		Configures the center frequency of the variable bandpass filter in the SPDIF input path. \n
			:param value: see the help for CfrequencyStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:CFRequency', value)

	# noinspection PyTypeChecker
	class BandwidthStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Bandwidth_Left: float: Bandwidth for left SPDIF channel Unit: Hz
			- Bandwidth_Right: float: Bandwidth for right SPDIF channel Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Bandwidth_Left'),
			ArgStruct.scalar_float('Bandwidth_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Bandwidth_Left: float = None
			self.Bandwidth_Right: float = None

	def get_bandwidth(self) -> BandwidthStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:BWIDth \n
		Snippet: value: BandwidthStruct = driver.configure.afRf.measurement.spdif.filterPy.bpass.get_bandwidth() \n
		Configures the bandwidth of the variable bandpass filter in the SPDIF input path. \n
			:return: structure: for return value, see the help for BandwidthStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:BWIDth?', self.__class__.BandwidthStruct())

	def set_bandwidth(self, value: BandwidthStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:BWIDth \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.bpass.set_bandwidth(value = BandwidthStruct()) \n
		Configures the bandwidth of the variable bandpass filter in the SPDIF input path. \n
			:param value: see the help for BandwidthStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:BPASs:BWIDth', value)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demod:
	"""Demod commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demod", core, parent)

	# noinspection PyTypeChecker
	def get_scheme(self) -> enums.Demodulation:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:DEMod:SCHeme \n
		Snippet: value: enums.Demodulation = driver.configure.afRf.measurement.searchRoutines.tx.demod.get_scheme() \n
		No command help available \n
			:return: scheme: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:DEMod:SCHeme?')
		return Conversions.str_to_scalar_enum(response, enums.Demodulation)

	def set_scheme(self, scheme: enums.Demodulation) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:DEMod:SCHeme \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.tx.demod.set_scheme(scheme = enums.Demodulation.AM) \n
		No command help available \n
			:param scheme: No help available
		"""
		param = Conversions.enum_scalar_to_str(scheme, enums.Demodulation)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:SROutines:TX:DEMod:SCHeme {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InternalGenerator:
	"""InternalGenerator commands group definition. 20 total commands, 10 Sub-groups, 0 group commands
	Repeated Capability: InternalGen, default value after init: InternalGen.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("internalGenerator", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_internalGen_get', 'repcap_internalGen_set', repcap.InternalGen.Nr1)

	def repcap_internalGen_set(self, enum_value: repcap.InternalGen) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to InternalGen.Default
		Default value after init: InternalGen.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_internalGen_get(self) -> repcap.InternalGen:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def enable(self):
		"""enable commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_enable'):
			from .InternalGenerator_.Enable import Enable
			self._enable = Enable(self._core, self._base)
		return self._enable

	@property
	def tmode(self):
		"""tmode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tmode'):
			from .InternalGenerator_.Tmode import Tmode
			self._tmode = Tmode(self._core, self._base)
		return self._tmode

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .InternalGenerator_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def dtone(self):
		"""dtone commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dtone'):
			from .InternalGenerator_.Dtone import Dtone
			self._dtone = Dtone(self._core, self._base)
		return self._dtone

	@property
	def multiTone(self):
		"""multiTone commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_multiTone'):
			from .InternalGenerator_.MultiTone import MultiTone
			self._multiTone = MultiTone(self._core, self._base)
		return self._multiTone

	@property
	def first(self):
		"""first commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_first'):
			from .InternalGenerator_.First import First
			self._first = First(self._core, self._base)
		return self._first

	@property
	def second(self):
		"""second commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_second'):
			from .InternalGenerator_.Second import Second
			self._second = Second(self._core, self._base)
		return self._second

	@property
	def third(self):
		"""third commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_third'):
			from .InternalGenerator_.Third import Third
			self._third = Third(self._core, self._base)
		return self._third

	@property
	def fourth(self):
		"""fourth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fourth'):
			from .InternalGenerator_.Fourth import Fourth
			self._fourth = Fourth(self._core, self._base)
		return self._fourth

	@property
	def dialing(self):
		"""dialing commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_dialing'):
			from .InternalGenerator_.Dialing import Dialing
			self._dialing = Dialing(self._core, self._base)
		return self._dialing

	def clone(self) -> 'InternalGenerator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = InternalGenerator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ........Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEMLeft:FDEViation:CURRent \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.oscilloscope.demodLeft.fdeviation.current.fetch() \n
		Queries the contents of the AF oscilloscope diagram for the left demodulator channel and FM demodulation or FM stereo
		demodulation. For FM stereo, the results are related to the left audio channel. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: dvt_time: Comma-separated list of 960 frequency deviation or audio deviation values (diagram from left to right) Unit: Hz"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEMLeft:FDEViation:CURRent?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEMLeft:FDEViation:CURRent \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.oscilloscope.demodLeft.fdeviation.current.read() \n
		Queries the contents of the AF oscilloscope diagram for the left demodulator channel and FM demodulation or FM stereo
		demodulation. For FM stereo, the results are related to the left audio channel. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: dvt_time: Comma-separated list of 960 frequency deviation or audio deviation values (diagram from left to right) Unit: Hz"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEMLeft:FDEViation:CURRent?', suppressed)
		return response



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FmStereo:
	"""FmStereo commands group definition. 4 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fmStereo", core, parent)

	@property
	def madeviation(self):
		"""madeviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_madeviation'):
			from .FmStereo_.Madeviation import Madeviation
			self._madeviation = Madeviation(self._core, self._base)
		return self._madeviation

	@property
	def pdeviation(self):
		"""pdeviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pdeviation'):
			from .FmStereo_.Pdeviation import Pdeviation
			self._pdeviation = Pdeviation(self._core, self._base)
		return self._pdeviation

	@property
	def rdsDeviation(self):
		"""rdsDeviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rdsDeviation'):
			from .FmStereo_.RdsDeviation import RdsDeviation
			self._rdsDeviation = RdsDeviation(self._core, self._base)
		return self._rdsDeviation

	def get_mdeviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:MODulator:FMSTereo:MDEViation \n
		Snippet: value: float = driver.source.afRf.generator.modulator.fmStereo.get_mdeviation() \n
		Queries the frequency deviation of the FM stereo multiplex signal. The value is calculated from the frequency deviations
		configured for the signal components. \n
			:return: max_freq_deviation: Range: 0 Hz to 100 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:MODulator:FMSTereo:MDEViation?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'FmStereo':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FmStereo(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Subnet:
	"""Subnet commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("subnet", core, parent)

	def get_mask(self) -> List[str]:
		"""SCPI: SYSTem:COMMunicate:NET:SUBNet:MASK \n
		Snippet: value: List[str] = driver.system.communicate.net.subnet.get_mask() \n
		Defines the subnet masks to be used for the network adapter. The configuration is only possible if DHCP is disabled.
		A query returns the currently used subnet masks, irrespective of whether they have been assigned manually or via DHCP. \n
			:return: subnet_mask: No help available
		"""
		response = self._core.io.query_str('SYSTem:COMMunicate:NET:SUBNet:MASK?')
		return Conversions.str_to_str_list(response)

	def set_mask(self, subnet_mask: List[str]) -> None:
		"""SCPI: SYSTem:COMMunicate:NET:SUBNet:MASK \n
		Snippet: driver.system.communicate.net.subnet.set_mask(subnet_mask = ['1', '2', '3']) \n
		Defines the subnet masks to be used for the network adapter. The configuration is only possible if DHCP is disabled.
		A query returns the currently used subnet masks, irrespective of whether they have been assigned manually or via DHCP. \n
			:param subnet_mask: String parameter, subnet mask consisting of four blocks separated by dots Several strings separated by commas can be entered, or several masks separated by commas can be included in one string.
		"""
		param = Conversions.list_to_csv_quoted_str(subnet_mask)
		self._core.io.write(f'SYSTem:COMMunicate:NET:SUBNet:MASK {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tsensitivity:
	"""Tsensitivity commands group definition. 25 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tsensitivity", core, parent)

	@property
	def voip(self):
		"""voip commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_voip'):
			from .Tsensitivity_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	@property
	def audioOutput(self):
		"""audioOutput commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioOutput'):
			from .Tsensitivity_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def fdeviation(self):
		"""fdeviation commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Tsensitivity_.Fdeviation import Fdeviation
			self._fdeviation = Fdeviation(self._core, self._base)
		return self._fdeviation

	@property
	def pdeviation(self):
		"""pdeviation commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_pdeviation'):
			from .Tsensitivity_.Pdeviation import Pdeviation
			self._pdeviation = Pdeviation(self._core, self._base)
		return self._pdeviation

	@property
	def modDepth(self):
		"""modDepth commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_modDepth'):
			from .Tsensitivity_.ModDepth import ModDepth
			self._modDepth = ModDepth(self._core, self._base)
		return self._modDepth

	def clone(self) -> 'Tsensitivity':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tsensitivity(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Auto:
	"""Auto commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("auto", core, parent)

	# noinspection PyTypeChecker
	class AutoStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Start_Freq: float: Frequency for tone 1 in the multitone list Range: 20 Hz to 20 kHz, Unit: Hz
			- Freq_Increment: float: Frequency increment for subsequent tones in the list Range: 1 Hz to 20 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_float('Start_Freq'),
			ArgStruct.scalar_float('Freq_Increment')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Start_Freq: float = None
			self.Freq_Increment: float = None

	def set(self, structure: AutoStruct, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:FREQuency:AUTO \n
		Snippet: driver.source.afRf.generator.internalGenerator.multiTone.frequency.auto.set(value = [PROPERTY_STRUCT_NAME](), internalGen = repcap.InternalGen.Default) \n
		Configures increasing equidistant frequencies for multitone generation. \n
			:param structure: for set value, see the help for AutoStruct structure arguments.
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write_struct(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:FREQuency:AUTO', structure)

	def get(self, internalGen=repcap.InternalGen.Default) -> AutoStruct:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:MTONe:FREQuency:AUTO \n
		Snippet: value: AutoStruct = driver.source.afRf.generator.internalGenerator.multiTone.frequency.auto.get(internalGen = repcap.InternalGen.Default) \n
		Configures increasing equidistant frequencies for multitone generation. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: structure: for return value, see the help for AutoStruct structure arguments."""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		return self._core.io.query_struct(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:MTONe:FREQuency:AUTO?', self.__class__.AutoStruct())



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AudioInput:
	"""AudioInput commands group definition. 6 total commands, 2 Sub-groups, 2 group commands
	Repeated Capability: AudioInput, default value after init: AudioInput.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("audioInput", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_audioInput_get', 'repcap_audioInput_set', repcap.AudioInput.Nr1)

	def repcap_audioInput_set(self, enum_value: repcap.AudioInput) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AudioInput.Default
		Default value after init: AudioInput.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_audioInput_get(self) -> repcap.AudioInput:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def sequence(self):
		"""sequence commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_sequence'):
			from .AudioInput_.Sequence import Sequence
			self._sequence = Sequence(self._core, self._base)
		return self._sequence

	@property
	def repetitions(self):
		"""repetitions commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_repetitions'):
			from .AudioInput_.Repetitions import Repetitions
			self._repetitions = Repetitions(self._core, self._base)
		return self._repetitions

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Length: int: Length of the tone sequence (number of digits)
			- Sequence: List[str]: Dialed digit as string
			- Frequency_1: List[float]: Nominal tone frequency according to the tone table Unit: Hz
			- Deviation_1: List[float]: Deviation of the measured tone frequency from the nominal tone frequency Unit: Hz
			- Fequency_2: List[float]: Second nominal frequency (only relevant for dual tones) Unit: Hz
			- Deviation_2: List[float]: Deviation of the second frequency (only relevant for dual tones) Unit: Hz
			- Time: List[float]: Measured tone duration Unit: s
			- Pause: List[float]: Duration of the pause between this tone and the next tone of the sequence Unit: s"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_int('Length'),
			ArgStruct('Sequence', DataType.StringList, None, False, True, 1),
			ArgStruct('Frequency_1', DataType.FloatList, None, False, True, 1),
			ArgStruct('Deviation_1', DataType.FloatList, None, False, True, 1),
			ArgStruct('Fequency_2', DataType.FloatList, None, False, True, 1),
			ArgStruct('Deviation_2', DataType.FloatList, None, False, True, 1),
			ArgStruct('Time', DataType.FloatList, None, False, True, 1),
			ArgStruct('Pause', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Length: int = None
			self.Sequence: List[str] = None
			self.Frequency_1: List[float] = None
			self.Deviation_1: List[float] = None
			self.Fequency_2: List[float] = None
			self.Deviation_2: List[float] = None
			self.Time: List[float] = None
			self.Pause: List[float] = None

	def fetch(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:AIN<Nr> \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.tones.audioInput.fetch(audioInput = repcap.AudioInput.Default) \n
		Queries all results of a tone sequence analysis. For each tone, a sequence of results is returned: <Reliability>,
		<Length>{, <Sequence>, <Frequency1>, <Deviation1>, <Frequency2>, <Deviation2>, <Time>, <Pause>}Tone 1, {...}Tone 2, ...
		, {...}Tone <Length> \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:TONes:AIN{audioInput_cmd_val}?', self.__class__.ResultData())

	def read(self, audioInput=repcap.AudioInput.Default) -> ResultData:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:TONes:AIN<Nr> \n
		Snippet: value: ResultData = driver.afRf.measurement.multiEval.tones.audioInput.read(audioInput = repcap.AudioInput.Default) \n
		Queries all results of a tone sequence analysis. For each tone, a sequence of results is returned: <Reliability>,
		<Length>{, <Sequence>, <Frequency1>, <Deviation1>, <Frequency2>, <Deviation2>, <Time>, <Pause>}Tone 1, {...}Tone 2, ...
		, {...}Tone <Length> \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for ResultData structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'READ:AFRF:MEASurement<Instance>:MEValuation:TONes:AIN{audioInput_cmd_val}?', self.__class__.ResultData())

	def clone(self) -> 'AudioInput':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AudioInput(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Types import DataType
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Length:
	"""Length commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("length", core, parent)

	def get(self, path_name: str = None) -> int:
		"""SCPI: MMEMory:DCATalog:LENGth \n
		Snippet: value: int = driver.massMemory.dcatalog.length.get(path_name = '1') \n
		Returns the number of subdirectories of the specified directory. The number corresponds to the number of strings returned
		by the method RsCma.MassMemory.Dcatalog.get_ command. \n
			:param path_name: String parameter to specify the directory. If the parameter is omitted, the command queries the contents of the current directory (see method RsCma.MassMemory.CurrentDirectory.set) . If the wildcards ? or * are used, the number of subdirectories matching this pattern are returned.
			:return: file_entry_count: No help available"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('path_name', path_name, DataType.String, True))
		response = self._core.io.query_str(f'MMEMory:DCATalog:LENGth? {param}'.rstrip())
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Application:
	"""Application commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("application", core, parent)

	def get_select(self) -> str:
		"""SCPI: CONFigure:DISPlay:APPLication:SELect \n
		Snippet: value: str = driver.configure.display.application.get_select() \n
		Selects the application to be displayed at the GUI. The command is useful as preparation for taking screenshots via
		remote commands. To make the GUI visible during remote control, use the command method RsCma.System.Display.update.
		To query a list of application selection strings, see method RsCma.Sense.Display.Applications.catalog. \n
			:return: current_app: String selecting the application
		"""
		response = self._core.io.query_str('CONFigure:DISPlay:APPLication:SELect?')
		return trim_str_response(response)

	def set_select(self, current_app: str) -> None:
		"""SCPI: CONFigure:DISPlay:APPLication:SELect \n
		Snippet: driver.configure.display.application.set_select(current_app = '1') \n
		Selects the application to be displayed at the GUI. The command is useful as preparation for taking screenshots via
		remote commands. To make the GUI visible during remote control, use the command method RsCma.System.Display.update.
		To query a list of application selection strings, see method RsCma.Sense.Display.Applications.catalog. \n
			:param current_app: String selecting the application
		"""
		param = Conversions.value_to_quoted_str(current_app)
		self._core.io.write(f'CONFigure:DISPlay:APPLication:SELect {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tplan:
	"""Tplan commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tplan", core, parent)

	def run(self, test_plan_name: str) -> None:
		"""SCPI: CONFigure:SEQuencer:TPLan:RUN \n
		Snippet: driver.configure.sequencer.tplan.run(test_plan_name = '1') \n
		No command help available \n
			:param test_plan_name: No help available
		"""
		param = Conversions.value_to_quoted_str(test_plan_name)
		self._core.io.write(f'CONFigure:SEQuencer:TPLan:RUN {param}')

	def abort(self, test_plan_name: str) -> None:
		"""SCPI: CONFigure:SEQuencer:TPLan:ABORt \n
		Snippet: driver.configure.sequencer.tplan.abort(test_plan_name = '1') \n
		No command help available \n
			:param test_plan_name: No help available
		"""
		param = Conversions.value_to_quoted_str(test_plan_name)
		self._core.io.write(f'CONFigure:SEQuencer:TPLan:ABORt {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Filter_Left_Enable: bool: No parameter help available
			- Filter_Right_Enable: bool: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Filter_Left_Enable'),
			ArgStruct.scalar_bool('Filter_Right_Enable')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Filter_Left_Enable: bool = None
			self.Filter_Right_Enable: bool = None

	def set(self, structure: EnableStruct, notch=repcap.Notch.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:NOTCh<Num>:ENABle \n
		Snippet: driver.configure.afRf.measurement.spdif.filterPy.notch.enable.set(value = [PROPERTY_STRUCT_NAME](), notch = repcap.Notch.Default) \n
		No command help available \n
			:param structure: for set value, see the help for EnableStruct structure arguments.
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')"""
		notch_cmd_val = self._base.get_repcap_cmd_value(notch, repcap.Notch)
		self._core.io.write_struct(f'CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:NOTCh{notch_cmd_val}:ENABle', structure)

	def get(self, notch=repcap.Notch.Default) -> EnableStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:NOTCh<Num>:ENABle \n
		Snippet: value: EnableStruct = driver.configure.afRf.measurement.spdif.filterPy.notch.enable.get(notch = repcap.Notch.Default) \n
		No command help available \n
			:param notch: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Notch')
			:return: structure: for return value, see the help for EnableStruct structure arguments."""
		notch_cmd_val = self._base.get_repcap_cmd_value(notch, repcap.Notch)
		return self._core.io.query_struct(f'CONFigure:AFRF:MEASurement<Instance>:SIN:FILTer:NOTCh{notch_cmd_val}:ENABle?', self.__class__.EnableStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Application:
	"""Application commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("application", core, parent)

	# noinspection PyTypeChecker
	class SelectStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Application: enums.SpecAnApp: FREQ | ZERO Show 'Frequency Sweep' subtab or 'Zero Span' subtab
			- Fullscreen: bool: OFF | ON OFF: show result diagram with default size ON: maximize result diagram"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Application', enums.SpecAnApp),
			ArgStruct.scalar_bool('Fullscreen')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Application: enums.SpecAnApp = None
			self.Fullscreen: bool = None

	# noinspection PyTypeChecker
	def get_select(self) -> SelectStruct:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:SPECtrum:APPLication:SELect \n
		Snippet: value: SelectStruct = driver.display.gprfMeasurement.spectrum.application.get_select() \n
		Configures the display of the 'Spectrum Analyzer' tab. \n
			:return: structure: for return value, see the help for SelectStruct structure arguments.
		"""
		return self._core.io.query_struct('DISPlay:GPRF:MEASurement<Instance>:SPECtrum:APPLication:SELect?', self.__class__.SelectStruct())

	def set_select(self, value: SelectStruct) -> None:
		"""SCPI: DISPlay:GPRF:MEASurement<Instance>:SPECtrum:APPLication:SELect \n
		Snippet: driver.display.gprfMeasurement.spectrum.application.set_select(value = SelectStruct()) \n
		Configures the display of the 'Spectrum Analyzer' tab. \n
			:param value: see the help for SelectStruct structure arguments.
		"""
		self._core.io.write_struct('DISPlay:GPRF:MEASurement<Instance>:SPECtrum:APPLication:SELect', value)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Attenuation:
	"""Attenuation commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("attenuation", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: CONFigure:BASE:ATTenuation:ENABle \n
		Snippet: value: bool = driver.configure.base.attenuation.get_enable() \n
		Enables or disables the internal 17 dB attenuator of the RF COM connector. \n
			:return: atten_enable: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:BASE:ATTenuation:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, atten_enable: bool) -> None:
		"""SCPI: CONFigure:BASE:ATTenuation:ENABle \n
		Snippet: driver.configure.base.attenuation.set_enable(atten_enable = False) \n
		Enables or disables the internal 17 dB attenuator of the RF COM connector. \n
			:param atten_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(atten_enable)
		self._core.io.write(f'CONFigure:BASE:ATTenuation:ENABle {param}')

	def get_awarning(self) -> bool:
		"""SCPI: CONFigure:BASE:ATTenuation:AWARning \n
		Snippet: value: bool = driver.configure.base.attenuation.get_awarning() \n
		Enables or disables an audible warning, to be played if the RF protection circuit is activated. \n
			:return: awarning: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:BASE:ATTenuation:AWARning?')
		return Conversions.str_to_bool(response)

	def set_awarning(self, awarning: bool) -> None:
		"""SCPI: CONFigure:BASE:ATTenuation:AWARning \n
		Snippet: driver.configure.base.attenuation.set_awarning(awarning = False) \n
		Enables or disables an audible warning, to be played if the RF protection circuit is activated. \n
			:param awarning: OFF | ON
		"""
		param = Conversions.bool_to_str(awarning)
		self._core.io.write(f'CONFigure:BASE:ATTenuation:AWARning {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cprotection:
	"""Cprotection commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cprotection", core, parent)

	def reset(self) -> None:
		"""SCPI: CONFigure:BASE:CPRotection:RESet \n
		Snippet: driver.configure.base.cprotection.reset() \n
		Resets the protection circuit of the RF connectors. \n
		"""
		self._core.io.write(f'CONFigure:BASE:CPRotection:RESet')

	def reset_with_opc(self) -> None:
		"""SCPI: CONFigure:BASE:CPRotection:RESet \n
		Snippet: driver.configure.base.cprotection.reset_with_opc() \n
		Resets the protection circuit of the RF connectors. \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'CONFigure:BASE:CPRotection:RESet')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scal:
	"""Scal commands group definition. 4 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("scal", core, parent)

	@property
	def userDefined(self):
		"""userDefined commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_userDefined'):
			from .Scal_.UserDefined import UserDefined
			self._userDefined = UserDefined(self._core, self._base)
		return self._userDefined

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_frequency'):
			from .Scal_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	def get_cfgenerator(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:CFGenerator \n
		Snippet: value: bool = driver.configure.afRf.measurement.multiEval.tones.scal.get_cfgenerator() \n
		Couples the SELCAL tone settings of the analyzer to the corresponding generator settings. \n
			:return: conf_from_gen: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:CFGenerator?')
		return Conversions.str_to_bool(response)

	def set_cfgenerator(self, conf_from_gen: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:CFGenerator \n
		Snippet: driver.configure.afRf.measurement.multiEval.tones.scal.set_cfgenerator(conf_from_gen = False) \n
		Couples the SELCAL tone settings of the analyzer to the corresponding generator settings. \n
			:param conf_from_gen: OFF | ON
		"""
		param = Conversions.bool_to_str(conf_from_gen)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:TONes:SCAL:CFGenerator {param}')

	def clone(self) -> 'Scal':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Scal(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 27 total commands, 8 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Power_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def elapsedStats(self):
		"""elapsedStats commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_elapsedStats'):
			from .Power_.ElapsedStats import ElapsedStats
			self._elapsedStats = ElapsedStats(self._core, self._base)
		return self._elapsedStats

	@property
	def current(self):
		"""current commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_current'):
			from .Power_.Current import Current
			self._current = Current(self._core, self._base)
		return self._current

	@property
	def minimum(self):
		"""minimum commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_minimum'):
			from .Power_.Minimum import Minimum
			self._minimum = Minimum(self._core, self._base)
		return self._minimum

	@property
	def maximum(self):
		"""maximum commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_maximum'):
			from .Power_.Maximum import Maximum
			self._maximum = Maximum(self._core, self._base)
		return self._maximum

	@property
	def average(self):
		"""average commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_average'):
			from .Power_.Average import Average
			self._average = Average(self._core, self._base)
		return self._average

	@property
	def peak(self):
		"""peak commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_peak'):
			from .Power_.Peak import Peak
			self._peak = Peak(self._core, self._base)
		return self._peak

	@property
	def standardDev(self):
		"""standardDev commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_standardDev'):
			from .Power_.StandardDev import StandardDev
			self._standardDev = StandardDev(self._core, self._base)
		return self._standardDev

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:POWer \n
		Snippet: driver.gprfMeasurement.power.initiate() \n
		Starts or continues the power measurement. \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:POWer')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:POWer \n
		Snippet: driver.gprfMeasurement.power.initiate_with_opc() \n
		Starts or continues the power measurement. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:POWer')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:POWer \n
		Snippet: driver.gprfMeasurement.power.stop() \n
		Pauses the power measurement. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:POWer')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:POWer \n
		Snippet: driver.gprfMeasurement.power.stop_with_opc() \n
		Pauses the power measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:POWer')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:POWer \n
		Snippet: driver.gprfMeasurement.power.abort() \n
		Stops the power measurement. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:POWer')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:POWer \n
		Snippet: driver.gprfMeasurement.power.abort_with_opc() \n
		Stops the power measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:POWer')

	def clone(self) -> 'Power':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Power(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ElapsedStats:
	"""ElapsedStats commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("elapsedStats", core, parent)

	def fetch(self) -> int:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:POWer:ESTatistics \n
		Snippet: value: int = driver.gprfMeasurement.power.elapsedStats.fetch() \n
		Queries the elapsed statistic count (progress bar) . \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: stat_count: Elapsed statistic count Range: 0 to configured statistic count"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:GPRF:MEASurement<Instance>:POWer:ESTatistics?', suppressed)
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FmStereo:
	"""FmStereo commands group definition. 6 total commands, 1 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("fmStereo", core, parent)

	@property
	def mdeviation(self):
		"""mdeviation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_mdeviation'):
			from .FmStereo_.Mdeviation import Mdeviation
			self._mdeviation = Mdeviation(self._core, self._base)
		return self._mdeviation

	# noinspection PyTypeChecker
	class AdeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper audio deviation limit Range: 0 Hz to 100 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_adeviation(self) -> AdeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:ADEViation \n
		Snippet: value: AdeviationStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.get_adeviation() \n
		Configures a limit for the audio deviation results, measured for FM stereo. \n
			:return: structure: for return value, see the help for AdeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:ADEViation?', self.__class__.AdeviationStruct())

	def set_adeviation(self, value: AdeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:ADEViation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.set_adeviation(value = AdeviationStruct()) \n
		Configures a limit for the audio deviation results, measured for FM stereo. \n
			:param value: see the help for AdeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:ADEViation', value)

	# noinspection PyTypeChecker
	class PiDeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper pilot deviation limit Range: 0 Hz to 10 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_pi_deviation(self) -> PiDeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PIDeviation \n
		Snippet: value: PiDeviationStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.get_pi_deviation() \n
		Configures a limit for the pilot deviation results, measured for FM stereo. \n
			:return: structure: for return value, see the help for PiDeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PIDeviation?', self.__class__.PiDeviationStruct())

	def set_pi_deviation(self, value: PiDeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PIDeviation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.set_pi_deviation(value = PiDeviationStruct()) \n
		Configures a limit for the pilot deviation results, measured for FM stereo. \n
			:param value: see the help for PiDeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PIDeviation', value)

	# noinspection PyTypeChecker
	class PfErrorStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower frequency error limit Range: -100 Hz to 0 Hz, Unit: Hz
			- Upper: float: Upper frequency error limit You can skip this setting. The Upper value equals always the Lower value times -1 (same absolute value, opposite sign) . Range: 0 Hz to 100 Hz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_pf_error(self) -> PfErrorStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PFERror \n
		Snippet: value: PfErrorStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.get_pf_error() \n
		Configures limits for the pilot frequency error, measured for FM stereo. \n
			:return: structure: for return value, see the help for PfErrorStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PFERror?', self.__class__.PfErrorStruct())

	def set_pf_error(self, value: PfErrorStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PFERror \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.set_pf_error(value = PfErrorStruct()) \n
		Configures limits for the pilot frequency error, measured for FM stereo. \n
			:param value: see the help for PfErrorStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:PFERror', value)

	# noinspection PyTypeChecker
	class RdsDeviationStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper RDS deviation limit Range: 0 Hz to 10 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_rds_deviation(self) -> RdsDeviationStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:RDSDeviation \n
		Snippet: value: RdsDeviationStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.get_rds_deviation() \n
		Configures a limit for the RDS deviation, measured for FM stereo. \n
			:return: structure: for return value, see the help for RdsDeviationStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:RDSDeviation?', self.__class__.RdsDeviationStruct())

	def set_rds_deviation(self, value: RdsDeviationStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:RDSDeviation \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.set_rds_deviation(value = RdsDeviationStruct()) \n
		Configures a limit for the RDS deviation, measured for FM stereo. \n
			:param value: see the help for RdsDeviationStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:RDSDeviation', value)

	def clone(self) -> 'FmStereo':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FmStereo(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dwidth:
	"""Dwidth commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dwidth", core, parent)

	# noinspection PyTypeChecker
	class DwidthStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Dwidth: enums.PwrFilterType: WIDE | NARRow Wide or narrow bandwidth
			- Relative: enums.Relative: RELative | CONStant Bandwidth proportional to reference frequency or constant"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Dwidth', enums.PwrFilterType),
			ArgStruct.scalar_enum('Relative', enums.Relative)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Dwidth: enums.PwrFilterType = None
			self.Relative: enums.Relative = None

	def set(self, structure: DwidthStruct, audioInput=repcap.AudioInput.Default) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:DWIDth \n
		Snippet: driver.configure.afRf.measurement.audioInput.filterPy.dwidth.set(value = [PROPERTY_STRUCT_NAME](), audioInput = repcap.AudioInput.Default) \n
		Configures the bandwidth of the distortion filter in an AF input path. \n
			:param structure: for set value, see the help for DwidthStruct structure arguments.
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')"""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		self._core.io.write_struct(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:DWIDth', structure)

	def get(self, audioInput=repcap.AudioInput.Default) -> DwidthStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN<nr>:FILTer:DWIDth \n
		Snippet: value: DwidthStruct = driver.configure.afRf.measurement.audioInput.filterPy.dwidth.get(audioInput = repcap.AudioInput.Default) \n
		Configures the bandwidth of the distortion filter in an AF input path. \n
			:param audioInput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'AudioInput')
			:return: structure: for return value, see the help for DwidthStruct structure arguments."""
		audioInput_cmd_val = self._base.get_repcap_cmd_value(audioInput, repcap.AudioInput)
		return self._core.io.query_struct(f'CONFigure:AFRF:MEASurement<Instance>:AIN{audioInput_cmd_val}:FILTer:DWIDth?', self.__class__.DwidthStruct())



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Frequency: List[float]: Frequency of the peak Unit: Hz
			- Level: List[float]: Level of the peak Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct('Frequency', DataType.FloatList, None, False, True, 1),
			ArgStruct('Level', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Frequency: List[float] = None
			self.Level: List[float] = None

	def read(self) -> ResultData:
		"""SCPI: READ:GPRF:MEASurement<Instance>:FFTSanalyzer:PEAKs:CURRent \n
		Snippet: value: ResultData = driver.gprfMeasurement.fftSpecAn.peaks.current.read() \n
		Queries the contents of the peak search result table. There are separate commands for the current and average spectrum
		traces. The results are returned in the following order: <Reliability>, {<Frequency>, <Level>}Peak 1, ..., {<Frequency>,
		<Level>}Peak 5 \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:GPRF:MEASurement<Instance>:FFTSanalyzer:PEAKs:CURRent?', self.__class__.ResultData())

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:PEAKs:CURRent \n
		Snippet: value: ResultData = driver.gprfMeasurement.fftSpecAn.peaks.current.fetch() \n
		Queries the contents of the peak search result table. There are separate commands for the current and average spectrum
		traces. The results are returned in the following order: <Reliability>, {<Frequency>, <Level>}Peak 1, ..., {<Frequency>,
		<Level>}Peak 5 \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:PEAKs:CURRent?', self.__class__.ResultData())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtFive:
	"""PtFive commands group definition. 16 total commands, 2 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ptFive", core, parent)

	@property
	def cqpsk(self):
		"""cqpsk commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_cqpsk'):
			from .PtFive_.Cqpsk import Cqpsk
			self._cqpsk = Cqpsk(self._core, self._base)
		return self._cqpsk

	@property
	def cfFm(self):
		"""cfFm commands group. 0 Sub-classes, 5 commands."""
		if not hasattr(self, '_cfFm'):
			from .PtFive_.CfFm import CfFm
			self._cfFm = CfFm(self._core, self._base)
		return self._cfFm

	def get_emergency(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:EMERgency \n
		Snippet: value: bool = driver.source.afRf.generator.ptFive.get_emergency() \n
		Configures the emergency bit to be signaled to the DUT, for P25. \n
			:return: emergency: OFF | ON
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:PTFive:EMERgency?')
		return Conversions.str_to_bool(response)

	def set_emergency(self, emergency: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:EMERgency \n
		Snippet: driver.source.afRf.generator.ptFive.set_emergency(emergency = False) \n
		Configures the emergency bit to be signaled to the DUT, for P25. \n
			:param emergency: OFF | ON
		"""
		param = Conversions.bool_to_str(emergency)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:PTFive:EMERgency {param}')

	def get_sid(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:SID \n
		Snippet: value: float = driver.source.afRf.generator.ptFive.get_sid() \n
		Configures the source ID to be signaled to the DUT. \n
			:return: source_id: Range: #H0 to #HFFFFFF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:PTFive:SID?')
		return Conversions.str_to_float(response)

	def set_sid(self, source_id: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:SID \n
		Snippet: driver.source.afRf.generator.ptFive.set_sid(source_id = 1.0) \n
		Configures the source ID to be signaled to the DUT. \n
			:param source_id: Range: #H0 to #HFFFFFF
		"""
		param = Conversions.decimal_value_to_str(source_id)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:PTFive:SID {param}')

	def get_tgid(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:TGID \n
		Snippet: value: float = driver.source.afRf.generator.ptFive.get_tgid() \n
		Configures the talk group ID to be signaled to the DUT. \n
			:return: tgroup_id: Range: #H0 to #HFFFF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:PTFive:TGID?')
		return Conversions.str_to_float(response)

	def set_tgid(self, tgroup_id: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:TGID \n
		Snippet: driver.source.afRf.generator.ptFive.set_tgid(tgroup_id = 1.0) \n
		Configures the talk group ID to be signaled to the DUT. \n
			:param tgroup_id: Range: #H0 to #HFFFF
		"""
		param = Conversions.decimal_value_to_str(tgroup_id)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:PTFive:TGID {param}')

	def get_nac(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:NAC \n
		Snippet: value: str = driver.source.afRf.generator.ptFive.get_nac() \n
		Configures the network access code to be signaled to the DUT. \n
			:return: nac: Range: #H0 to #HFFF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:PTFive:NAC?')
		return trim_str_response(response)

	def set_nac(self, nac: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:NAC \n
		Snippet: driver.source.afRf.generator.ptFive.set_nac(nac = r1) \n
		Configures the network access code to be signaled to the DUT. \n
			:param nac: Range: #H0 to #HFFF
		"""
		param = Conversions.value_to_str(nac)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:PTFive:NAC {param}')

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.P25Pattern:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:PATTern \n
		Snippet: value: enums.P25Pattern = driver.source.afRf.generator.ptFive.get_pattern() \n
		Selects the bit pattern to be transmitted as payload for P25. \n
			:return: pattern: P1011 | SILence | INTerference | BUSY | IDLE | CALibration
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:PTFive:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.P25Pattern)

	def set_pattern(self, pattern: enums.P25Pattern) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:PATTern \n
		Snippet: driver.source.afRf.generator.ptFive.set_pattern(pattern = enums.P25Pattern.BUSY) \n
		Selects the bit pattern to be transmitted as payload for P25. \n
			:param pattern: P1011 | SILence | INTerference | BUSY | IDLE | CALibration
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.P25Pattern)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:PTFive:PATTern {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.P25Mode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:MODE \n
		Snippet: value: enums.P25Mode = driver.source.afRf.generator.ptFive.get_mode() \n
		Specifies the modulation type used for P25 phase 1 modulation. \n
			:return: mode: C4FM | CQPSk
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:PTFive:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.P25Mode)

	def set_mode(self, mode: enums.P25Mode) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:MODE \n
		Snippet: driver.source.afRf.generator.ptFive.set_mode(mode = enums.P25Mode.C4FM) \n
		Specifies the modulation type used for P25 phase 1 modulation. \n
			:param mode: C4FM | CQPSk
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.P25Mode)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:PTFive:MODE {param}')

	def clone(self) -> 'PtFive':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PtFive(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 9 total commands, 2 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Data_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def fsk(self):
		"""fsk commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fsk'):
			from .Data_.Fsk import Fsk
			self._fsk = Fsk(self._core, self._base)
		return self._fsk

	def initiate(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:DATA \n
		Snippet: driver.afRf.measurement.data.initiate() \n
		Starts or continues the measurement. \n
		"""
		self._core.io.write(f'INITiate:AFRF:MEASurement<Instance>:DATA')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:AFRF:MEASurement<Instance>:DATA \n
		Snippet: driver.afRf.measurement.data.initiate_with_opc() \n
		Starts or continues the measurement. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:AFRF:MEASurement<Instance>:DATA')

	def stop(self) -> None:
		"""SCPI: STOP:AFRF:MEASurement<Instance>:DATA \n
		Snippet: driver.afRf.measurement.data.stop() \n
		Pauses the measurement. \n
		"""
		self._core.io.write(f'STOP:AFRF:MEASurement<Instance>:DATA')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:AFRF:MEASurement<Instance>:DATA \n
		Snippet: driver.afRf.measurement.data.stop_with_opc() \n
		Pauses the measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:AFRF:MEASurement<Instance>:DATA')

	def abort(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:DATA \n
		Snippet: driver.afRf.measurement.data.abort() \n
		Stops the measurement. \n
		"""
		self._core.io.write(f'ABORt:AFRF:MEASurement<Instance>:DATA')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:AFRF:MEASurement<Instance>:DATA \n
		Snippet: driver.afRf.measurement.data.abort_with_opc() \n
		Stops the measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:AFRF:MEASurement<Instance>:DATA')

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Action:
	"""Action commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("action", core, parent)

	def set(self) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:FARFrequency:ACTion \n
		Snippet: driver.source.afRf.generator.rfSettings.farFrequency.action.set() \n
		Sets the reference frequency of the channel definition to the current RF carrier center frequency. \n
		"""
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:RFSettings:FARFrequency:ACTion')

	def set_with_opc(self) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:RFSettings:FARFrequency:ACTion \n
		Snippet: driver.source.afRf.generator.rfSettings.farFrequency.action.set_with_opc() \n
		Sets the reference frequency of the channel definition to the current RF carrier center frequency. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:RFSettings:FARFrequency:ACTion')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Current:
	"""Current commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("current", core, parent)

	def fetch(self) -> float:
		"""SCPI: FETCh:VSE:MEASurement<Instance>:FDERror:CURRent \n
		Snippet: value: float = driver.vse.measurement.fdError.current.fetch() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: fsk_deviation_error: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'FETCh:VSE:MEASurement<Instance>:FDERror:CURRent?', suppressed)
		return Conversions.str_to_float(response)

	def read(self) -> float:
		"""SCPI: READ:VSE:MEASurement<Instance>:FDERror:CURRent \n
		Snippet: value: float = driver.vse.measurement.fdError.current.read() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: fsk_deviation_error: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'READ:VSE:MEASurement<Instance>:FDERror:CURRent?', suppressed)
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def calculate(self) -> enums.ResultStatus:
		"""SCPI: CALCulate:VSE:MEASurement<Instance>:FDERror:CURRent \n
		Snippet: value: enums.ResultStatus = driver.vse.measurement.fdError.current.calculate() \n
		No command help available \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: fsk_deviation_error: No help available"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_str_suppressed(f'CALCulate:VSE:MEASurement<Instance>:FDERror:CURRent?', suppressed)
		return Conversions.str_to_scalar_enum(response, enums.ResultStatus)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Swt:
	"""Swt commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("swt", core, parent)

	def get_auto(self) -> bool:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT:AUTO \n
		Snippet: value: bool = driver.configure.gprfMeasurement.spectrum.freqSweep.swt.get_auto() \n
		Enables or disables automatic configuration of the sweep time for the frequency sweep mode. \n
			:return: sweep_time_auto: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT:AUTO?')
		return Conversions.str_to_bool(response)

	def set_auto(self, sweep_time_auto: bool) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT:AUTO \n
		Snippet: driver.configure.gprfMeasurement.spectrum.freqSweep.swt.set_auto(sweep_time_auto = False) \n
		Enables or disables automatic configuration of the sweep time for the frequency sweep mode. \n
			:param sweep_time_auto: OFF | ON
		"""
		param = Conversions.bool_to_str(sweep_time_auto)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT:AUTO {param}')

	def get_value(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT \n
		Snippet: value: float = driver.configure.gprfMeasurement.spectrum.freqSweep.swt.get_value() \n
		Specifies the sweep time for the frequency sweep mode. Setting this value is only possible if the automatic configuration
		is switched off, see method RsCma.Configure.GprfMeasurement.Spectrum.FreqSweep.Swt.auto. \n
			:return: sweep_time: Range: 3.99602E-3 s to 2000 s, Unit: s
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT?')
		return Conversions.str_to_float(response)

	def set_value(self, sweep_time: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT \n
		Snippet: driver.configure.gprfMeasurement.spectrum.freqSweep.swt.set_value(sweep_time = 1.0) \n
		Specifies the sweep time for the frequency sweep mode. Setting this value is only possible if the automatic configuration
		is switched off, see method RsCma.Configure.GprfMeasurement.Spectrum.FreqSweep.Swt.auto. \n
			:param sweep_time: Range: 3.99602E-3 s to 2000 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(sweep_time)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:SPECtrum:FSWeep:SWT {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ExtPwrSensor:
	"""ExtPwrSensor commands group definition. 8 total commands, 1 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("extPwrSensor", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .ExtPwrSensor_.State import State
			self._state = State(self._core, self._base)
		return self._state

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: driver.gprfMeasurement.extPwrSensor.initiate() \n
		Starts or continues the EPS measurement. \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:EPSensor')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: driver.gprfMeasurement.extPwrSensor.initiate_with_opc() \n
		Starts or continues the EPS measurement. \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:EPSensor')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: driver.gprfMeasurement.extPwrSensor.stop() \n
		Pauses the EPS measurement. \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:EPSensor')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: driver.gprfMeasurement.extPwrSensor.stop_with_opc() \n
		Pauses the EPS measurement. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:EPSensor')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: driver.gprfMeasurement.extPwrSensor.abort() \n
		Stops the EPS measurement. \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:EPSensor')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: driver.gprfMeasurement.extPwrSensor.abort_with_opc() \n
		Stops the EPS measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:EPSensor')

	def get_idn(self) -> str:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:EPSensor:IDN \n
		Snippet: value: str = driver.gprfMeasurement.extPwrSensor.get_idn() \n
		Queries the identification string of the connected external power sensor. \n
			:return: idn: String parameter
		"""
		response = self._core.io.query_str('FETCh:GPRF:MEASurement<Instance>:EPSensor:IDN?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	class ResultData(StructBase):
		"""Response structure. Fields: \n
			- Reliability: int: See 'Reliability indicator values'
			- Current_Power: float: Sensor power in the last measurement interval Unit: dBm
			- Average_Power: float: Average of all CurrentPower values within the last measurement cycle Unit: dBm
			- Minimum_Power: float: Minimum CurrentPower value since the start of the measurement Unit: dBm
			- Maximum_Power: float: Maximum CurrentPower value since the start of the measurement Unit: dBm
			- Elapsed_Stat: int: Elapsed statistic count (progress bar) Range: 0 to configured statistic count"""
		__meta_args_list = [
			ArgStruct.scalar_int('Reliability', 'Reliability'),
			ArgStruct.scalar_float('Current_Power'),
			ArgStruct.scalar_float('Average_Power'),
			ArgStruct.scalar_float('Minimum_Power'),
			ArgStruct.scalar_float('Maximum_Power'),
			ArgStruct.scalar_int('Elapsed_Stat')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Reliability: int = None
			self.Current_Power: float = None
			self.Average_Power: float = None
			self.Minimum_Power: float = None
			self.Maximum_Power: float = None
			self.Elapsed_Stat: int = None

	def fetch(self) -> ResultData:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: value: ResultData = driver.gprfMeasurement.extPwrSensor.fetch() \n
		Return all EPS measurement results. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'FETCh:GPRF:MEASurement<Instance>:EPSensor?', self.__class__.ResultData())

	def read(self) -> ResultData:
		"""SCPI: READ:GPRF:MEASurement<Instance>:EPSensor \n
		Snippet: value: ResultData = driver.gprfMeasurement.extPwrSensor.read() \n
		Return all EPS measurement results. \n
			:return: structure: for return value, see the help for ResultData structure arguments."""
		return self._core.io.query_struct(f'READ:GPRF:MEASurement<Instance>:EPSensor?', self.__class__.ResultData())

	def clone(self) -> 'ExtPwrSensor':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ExtPwrSensor(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Arb:
	"""Arb commands group definition. 6 total commands, 2 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("arb", core, parent)

	@property
	def catalog(self):
		"""catalog commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Arb_.Catalog import Catalog
			self._catalog = Catalog(self._core, self._base)
		return self._catalog

	@property
	def manual(self):
		"""manual commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_manual'):
			from .Arb_.Manual import Manual
			self._manual = Manual(self._core, self._base)
		return self._manual

	def get_autostart(self) -> bool:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:AUTostart \n
		Snippet: value: bool = driver.trigger.afRf.generator.arb.get_autostart() \n
		Enables or disables the automatic start of the loaded ARB file whenever the generator is turned on. This setting applies
		only to the 'Manual' trigger source. For other trigger sources, autostart is disabled. \n
			:return: autostart: OFF | ON
		"""
		response = self._core.io.query_str('TRIGger:AFRF:GENerator<Instance>:ARB:AUTostart?')
		return Conversions.str_to_bool(response)

	def set_autostart(self, autostart: bool) -> None:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:AUTostart \n
		Snippet: driver.trigger.afRf.generator.arb.set_autostart(autostart = False) \n
		Enables or disables the automatic start of the loaded ARB file whenever the generator is turned on. This setting applies
		only to the 'Manual' trigger source. For other trigger sources, autostart is disabled. \n
			:param autostart: OFF | ON
		"""
		param = Conversions.bool_to_str(autostart)
		self._core.io.write(f'TRIGger:AFRF:GENerator<Instance>:ARB:AUTostart {param}')

	def get_delay(self) -> float:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:DELay \n
		Snippet: value: float = driver.trigger.afRf.generator.arb.get_delay() \n
		Specifies a start delay relative to the trigger event. This setting is ignored for the 'Manual' trigger source. \n
			:return: delay: Range: 0 s to 100 s, Unit: s
		"""
		response = self._core.io.query_str('TRIGger:AFRF:GENerator<Instance>:ARB:DELay?')
		return Conversions.str_to_float(response)

	def set_delay(self, delay: float) -> None:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:DELay \n
		Snippet: driver.trigger.afRf.generator.arb.set_delay(delay = 1.0) \n
		Specifies a start delay relative to the trigger event. This setting is ignored for the 'Manual' trigger source. \n
			:param delay: Range: 0 s to 100 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(delay)
		self._core.io.write(f'TRIGger:AFRF:GENerator<Instance>:ARB:DELay {param}')

	def get_retrigger(self) -> bool:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:RETRigger \n
		Snippet: value: bool = driver.trigger.afRf.generator.arb.get_retrigger() \n
		Specifies whether trigger events during ARB file processing restart the ARB file or not. This setting applies only to the
		'Manual' trigger source. For other trigger sources, retriggering is disabled. \n
			:return: retrigger: OFF | ON
		"""
		response = self._core.io.query_str('TRIGger:AFRF:GENerator<Instance>:ARB:RETRigger?')
		return Conversions.str_to_bool(response)

	def set_retrigger(self, retrigger: bool) -> None:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:RETRigger \n
		Snippet: driver.trigger.afRf.generator.arb.set_retrigger(retrigger = False) \n
		Specifies whether trigger events during ARB file processing restart the ARB file or not. This setting applies only to the
		'Manual' trigger source. For other trigger sources, retriggering is disabled. \n
			:param retrigger: OFF | ON
		"""
		param = Conversions.bool_to_str(retrigger)
		self._core.io.write(f'TRIGger:AFRF:GENerator<Instance>:ARB:RETRigger {param}')

	def get_source(self) -> str:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:SOURce \n
		Snippet: value: str = driver.trigger.afRf.generator.arb.get_source() \n
		Selects the trigger event source used to start or restart ARB file processing. To query a list of all supported sources,
		use method RsCma.Trigger.AfRf.Generator.Arb.Catalog.source. \n
			:return: source: 'Manual' Manual start via method RsCma.Trigger.AfRf.Generator.Arb.Manual.Execute.set 'Base1: External TRIG In' External trigger signal received at connector TRIG IN
		"""
		response = self._core.io.query_str('TRIGger:AFRF:GENerator<Instance>:ARB:SOURce?')
		return trim_str_response(response)

	def set_source(self, source: str) -> None:
		"""SCPI: TRIGger:AFRF:GENerator<Instance>:ARB:SOURce \n
		Snippet: driver.trigger.afRf.generator.arb.set_source(source = '1') \n
		Selects the trigger event source used to start or restart ARB file processing. To query a list of all supported sources,
		use method RsCma.Trigger.AfRf.Generator.Arb.Catalog.source. \n
			:param source: 'Manual' Manual start via method RsCma.Trigger.AfRf.Generator.Arb.Manual.Execute.set 'Base1: External TRIG In' External trigger signal received at connector TRIG IN
		"""
		param = Conversions.value_to_quoted_str(source)
		self._core.io.write(f'TRIGger:AFRF:GENerator<Instance>:ARB:SOURce {param}')

	def clone(self) -> 'Arb':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Arb(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def get_date(self) -> str:
		"""SCPI: SOURce:XRT:GENerator<Instance>:ARB:FILE:DATE \n
		Snippet: value: str = driver.source.xrt.generator.arb.file.get_date() \n
		No command help available \n
			:return: date: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:ARB:FILE:DATE?')
		return trim_str_response(response)

	def get_option(self) -> str:
		"""SCPI: SOURce:XRT:GENerator<Instance>:ARB:FILE:OPTion \n
		Snippet: value: str = driver.source.xrt.generator.arb.file.get_option() \n
		No command help available \n
			:return: options: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:ARB:FILE:OPTion?')
		return trim_str_response(response)

	def get_version(self) -> str:
		"""SCPI: SOURce:XRT:GENerator<Instance>:ARB:FILE:VERSion \n
		Snippet: value: str = driver.source.xrt.generator.arb.file.get_version() \n
		No command help available \n
			:return: version: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:ARB:FILE:VERSion?')
		return trim_str_response(response)

	def get_value(self) -> str:
		"""SCPI: SOURce:XRT:GENerator<Instance>:ARB:FILE \n
		Snippet: value: str = driver.source.xrt.generator.arb.file.get_value() \n
		No command help available \n
			:return: arb_file: No help available
		"""
		response = self._core.io.query_str('SOURce:XRT:GENerator<Instance>:ARB:FILE?')
		return trim_str_response(response)

	def set_value(self, arb_file: str) -> None:
		"""SCPI: SOURce:XRT:GENerator<Instance>:ARB:FILE \n
		Snippet: driver.source.xrt.generator.arb.file.set_value(arb_file = '1') \n
		No command help available \n
			:param arb_file: No help available
		"""
		param = Conversions.value_to_quoted_str(arb_file)
		self._core.io.write(f'SOURce:XRT:GENerator<Instance>:ARB:FILE {param}')



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardDev:
	"""StandardDev commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("standardDev", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:ACP:ACLR:SDEViation \n
		Snippet: value: List[float] = driver.gprfMeasurement.acp.aclr.standardDev.fetch() \n
		Queries the ACLR results. There are separate commands for the current, average, maximum and standard deviation values.
		CALCulate commands return error indicators instead of measurement values. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: aclr: Comma-separated list of five ACLR values, one per channel: Channel -2, -1, 0, +1, +2 Unit: dB"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:ACP:ACLR:SDEViation?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:ACP:ACLR:SDEViation \n
		Snippet: value: List[float] = driver.gprfMeasurement.acp.aclr.standardDev.read() \n
		Queries the ACLR results. There are separate commands for the current, average, maximum and standard deviation values.
		CALCulate commands return error indicators instead of measurement values. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: aclr: Comma-separated list of five ACLR values, one per channel: Channel -2, -1, 0, +1, +2 Unit: dB"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:ACP:ACLR:SDEViation?', suppressed)
		return response

	def calculate(self) -> List[float]:
		"""SCPI: CALCulate:GPRF:MEASurement<Instance>:ACP:ACLR:SDEViation \n
		Snippet: value: List[float] = driver.gprfMeasurement.acp.aclr.standardDev.calculate() \n
		Queries the ACLR results. There are separate commands for the current, average, maximum and standard deviation values.
		CALCulate commands return error indicators instead of measurement values. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: aclr: Comma-separated list of five ACLR values, one per channel: Channel -2, -1, 0, +1, +2 Unit: dB"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'CALCulate:GPRF:MEASurement<Instance>:ACP:ACLR:SDEViation?', suppressed)
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AudioOutput:
	"""AudioOutput commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("audioOutput", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:ENABle \n
		Snippet: value: bool = driver.source.avionics.generator.vor.afSettings.audioOutput.get_enable() \n
		Enables or disables the AF output path. \n
			:return: af_enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, af_enable: bool) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:ENABle \n
		Snippet: driver.source.avionics.generator.vor.afSettings.audioOutput.set_enable(af_enable = False) \n
		Enables or disables the AF output path. \n
			:param af_enable: OFF | ON
		"""
		param = Conversions.bool_to_str(af_enable)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:ENABle {param}')

	def get_level(self) -> float:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:LEVel \n
		Snippet: value: float = driver.source.avionics.generator.vor.afSettings.audioOutput.get_level() \n
		Specifies the output level for the AF output path. \n
			:return: level: Range: 10E-6 V to 5 V, Unit: V
		"""
		response = self._core.io.query_str('SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:LEVel \n
		Snippet: driver.source.avionics.generator.vor.afSettings.audioOutput.set_level(level = 1.0) \n
		Specifies the output level for the AF output path. \n
			:param level: Range: 10E-6 V to 5 V, Unit: V
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AVIonics:GENerator<Instance>:VOR:AFSettings:AOUT:LEVel {param}')



from typing import List

from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ........Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Maximum:
	"""Maximum commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("maximum", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:DEMLeft:FDEViation:MAXimum \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.fft.demodLeft.fdeviation.maximum.fetch() \n
		Queries the contents of the spectrum diagram for the left demodulator channel and FM demodulation or FM stereo
		demodulation. For FM stereo, these results are related to the left audio channel. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Comma-separated list of 1793 frequency deviation or audio deviation values (diagram from left to right) Unit: dBHz"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:AFRF:MEASurement<Instance>:MEValuation:FFT:DEMLeft:FDEViation:MAXimum?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:AFRF:MEASurement<Instance>:MEValuation:FFT:DEMLeft:FDEViation:MAXimum \n
		Snippet: value: List[float] = driver.afRf.measurement.multiEval.fft.demodLeft.fdeviation.maximum.read() \n
		Queries the contents of the spectrum diagram for the left demodulator channel and FM demodulation or FM stereo
		demodulation. For FM stereo, these results are related to the left audio channel. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Comma-separated list of 1793 frequency deviation or audio deviation values (diagram from left to right) Unit: dBHz"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:AFRF:MEASurement<Instance>:MEValuation:FFT:DEMLeft:FDEViation:MAXimum?', suppressed)
		return response



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Generator:
	"""Generator commands group definition. 3 total commands, 1 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("generator", core, parent)

	@property
	def condition(self):
		"""condition commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_condition'):
			from .Generator_.Condition import Condition
			self._condition = Condition(self._core, self._base)
		return self._condition

	def clone(self) -> 'Generator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Generator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dcs:
	"""Dcs commands group definition. 8 total commands, 2 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dcs", core, parent)

	@property
	def ifsk(self):
		"""ifsk commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ifsk'):
			from .Dcs_.Ifsk import Ifsk
			self._ifsk = Ifsk(self._core, self._base)
		return self._ifsk

	@property
	def toCode(self):
		"""toCode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toCode'):
			from .Dcs_.ToCode import ToCode
			self._toCode = ToCode(self._core, self._base)
		return self._toCode

	def get_cword(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:CWORd \n
		Snippet: value: str = driver.source.afRf.generator.tones.dcs.get_cword() \n
		Specifies the DCS code number. \n
			:return: sequence: DCS code number as octal number Not allowed octal numbers are automatically rounded to the closest allowed value. Range: #Q20 to #Q777
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:CWORd?')
		return trim_str_response(response)

	def set_cword(self, sequence: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:CWORd \n
		Snippet: driver.source.afRf.generator.tones.dcs.set_cword(sequence = r1) \n
		Specifies the DCS code number. \n
			:param sequence: DCS code number as octal number Not allowed octal numbers are automatically rounded to the closest allowed value. Range: #Q20 to #Q777
		"""
		param = Conversions.value_to_str(sequence)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:DCS:CWORd {param}')

	def get_enable(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:ENABle \n
		Snippet: value: bool = driver.source.afRf.generator.tones.dcs.get_enable() \n
		Enables or disables the DCS signal. \n
			:return: enable: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:ENABle \n
		Snippet: driver.source.afRf.generator.tones.dcs.set_enable(enable = False) \n
		Enables or disables the DCS signal. \n
			:param enable: OFF | ON
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:DCS:ENABle {param}')

	def get_fsk_deviation(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:FSKDeviation \n
		Snippet: value: float = driver.source.afRf.generator.tones.dcs.get_fsk_deviation() \n
		Specifies the frequency deviation used for FSK modulation of the carrier with the DCS bit stream. \n
			:return: fsk_dev: Range: 0 Hz to 10 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:FSKDeviation?')
		return Conversions.str_to_float(response)

	def set_fsk_deviation(self, fsk_dev: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:FSKDeviation \n
		Snippet: driver.source.afRf.generator.tones.dcs.set_fsk_deviation(fsk_dev = 1.0) \n
		Specifies the frequency deviation used for FSK modulation of the carrier with the DCS bit stream. \n
			:param fsk_dev: Range: 0 Hz to 10 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(fsk_dev)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:DCS:FSKDeviation {param}')

	def get_drate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:DRATe \n
		Snippet: value: float = driver.source.afRf.generator.tones.dcs.get_drate() \n
		Queries the data rate used for DCS bit stream transmission. \n
			:return: bitrate: Range: 104.4 bit/s to 164.4 bit/s, Unit: bit/s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:DRATe?')
		return Conversions.str_to_float(response)

	def get_dr_offset(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:DROFfset \n
		Snippet: value: float = driver.source.afRf.generator.tones.dcs.get_dr_offset() \n
		Modifies the used data rate by defining an offset relative to the nominal data rate of 134.4 Bit/s. \n
			:return: roffset: Range: -30 bit/s to 30 bit/s, Unit: bit/s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:DROFfset?')
		return Conversions.str_to_float(response)

	def set_dr_offset(self, roffset: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:DROFfset \n
		Snippet: driver.source.afRf.generator.tones.dcs.set_dr_offset(roffset = 1.0) \n
		Modifies the used data rate by defining an offset relative to the nominal data rate of 134.4 Bit/s. \n
			:param roffset: Range: -30 bit/s to 30 bit/s, Unit: bit/s
		"""
		param = Conversions.decimal_value_to_str(roffset)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:DCS:DROFfset {param}')

	def get_toc_length(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:TOCLength \n
		Snippet: value: float = driver.source.afRf.generator.tones.dcs.get_toc_length() \n
		Specifies the duration of turn-off code transmissions. \n
			:return: off_length: Range: 0 s to 1 s, Unit: s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:TONes:DCS:TOCLength?')
		return Conversions.str_to_float(response)

	def set_toc_length(self, off_length: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:TONes:DCS:TOCLength \n
		Snippet: driver.source.afRf.generator.tones.dcs.set_toc_length(off_length = 1.0) \n
		Specifies the duration of turn-off code transmissions. \n
			:param off_length: Range: 0 s to 1 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(off_length)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:TONes:DCS:TOCLength {param}')

	def clone(self) -> 'Dcs':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dcs(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Delta:
	"""Delta commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("delta", core, parent)

	def get_user(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:LEVel:DELTa:USER \n
		Snippet: value: float = driver.configure.afRf.measurement.audioInput.first.level.delta.get_user() \n
		No command help available \n
			:return: user_val: Unit: V
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:LEVel:DELTa:USER?')
		return Conversions.str_to_float(response)

	def set_user(self, user_val: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:LEVel:DELTa:USER \n
		Snippet: driver.configure.afRf.measurement.audioInput.first.level.delta.set_user(user_val = 1.0) \n
		No command help available \n
			:param user_val: Unit: V
		"""
		param = Conversions.decimal_value_to_str(user_val)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:LEVel:DELTa:USER {param}')

	def get_measured(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:LEVel:DELTa:MEASured \n
		Snippet: value: float = driver.configure.afRf.measurement.audioInput.first.level.delta.get_measured() \n
		No command help available \n
			:return: meas_val: Unit: V
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:AIN:FIRSt:LEVel:DELTa:MEASured?')
		return Conversions.str_to_float(response)
